==> haskell-bytestring-encoding-0.1.1.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-encoding
version:              0.1.1.0
visibility:           public
id:                   bytestring-encoding-0.1.1.0-AjO4WeYPYm86FBYOQwAXX
key:                  bytestring-encoding-0.1.1.0-AjO4WeYPYm86FBYOQwAXX
license:              BSD-3-Clause
copyright:            2018 Masahiro Sakai
maintainer:           masahiro.sakai@gmail.com
author:               Masahiro Sakai
homepage:             https://github.com/msakai/bytestring-encoding#readme
synopsis:             ByteString ↔ Text converter based on GHC.IO.Encoding
description:
    Please see the README on GitHub at <https://github.com/msakai/bytestring-encoding#readme>

category:             Data, Text
abi:                  949be92039a918196cc1edcd67b59d85
exposed:              True
exposed-modules:
    Data.ByteString.Encoding Data.ByteString.Lazy.Encoding
    Data.ByteString.Lazy.Encoding.Internal

hidden-modules:       Paths_bytestring_encoding
import-dirs:          /usr/lib/ghc-9.0.1/site-local/bytestring-encoding-0.1.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bytestring-encoding-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/bytestring-encoding-0.1.1.0

hs-libraries:         HSbytestring-encoding-0.1.1.0-AjO4WeYPYm86FBYOQwAXX
depends:              base-4.15.0.0 bytestring-0.10.12.1 text-1.2.4.1
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-encoding/html/bytestring-encoding.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-encoding-0.1.1.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-encoding
version:              0.1.1.0
visibility:           public
id:                   bytestring-encoding-0.1.1.0-3gaJI3PE4BIGsDrFx2EXzx
key:                  bytestring-encoding-0.1.1.0-3gaJI3PE4BIGsDrFx2EXzx
license:              BSD-3-Clause
copyright:            2018 Masahiro Sakai
maintainer:           masahiro.sakai@gmail.com
author:               Masahiro Sakai
homepage:             https://github.com/msakai/bytestring-encoding#readme
synopsis:             ByteString ↔ Text converter based on GHC.IO.Encoding
description:
    Please see the README on GitHub at <https://github.com/msakai/bytestring-encoding#readme>

category:             Data, Text
abi:                  8d03996cc745da2aee499c33d6137f91
exposed:              True
exposed-modules:
    Data.ByteString.Encoding Data.ByteString.Lazy.Encoding
    Data.ByteString.Lazy.Encoding.Internal

hidden-modules:       Paths_bytestring_encoding
import-dirs:          /usr/lib/ghc-9.0.1/site-local/bytestring-encoding-0.1.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bytestring-encoding-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/bytestring-encoding-0.1.1.0

hs-libraries:         HSbytestring-encoding-0.1.1.0-3gaJI3PE4BIGsDrFx2EXzx
depends:              base-4.15.0.0 bytestring-0.10.12.1 text-1.2.4.1
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-encoding/html/bytestring-encoding.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
